use sandbox_diffusion_2021_data.dta, replace
*install required programs. Skip if you already install them
ssc install asdoc
ssc install spmap
ssc install shp2dta
ssc install mif2dta
*table 1 proposed vs enforced countries 
asdoc list country inforcedate if sandboxin==1 | sandboxpro==1, save(t1_country) replace
*Fig 1 & 2 
spmap sandall using coord, id(id)fcolor(Blues) title("Sandbox diffusion in the World") clme(unique) legc legend(size(*2.5))
graph export worldmap.png, as(png) replace
spmap inforcedate using coord, id(id)fcolor(Reds) title("Sandbox diffusion by time") clnumber(6) legend(size(*1.5))
graph export worldbytime.png, as(png) replace
*region 
ta region sandboxin, chi
ta region sandboxpro, chi 
list ISO3N country region inforcedate if sandboxin==1 & region ==4
list ISO3N country region inforcedate if sandboxin==1 & region ==7
*statistical analysis country data
*table 2 descriptive stat 
asdoc sum sandboxin lGDPPC lnpop2015 stockcap fiopenn Hstat lerner boone bankcon ///
forbasset common commonlaw civil bcolony commonwealth BIS FSB BCBS IOSCO AFI ///
, save(t2_SUMtab) label star(0.05) dec(2) replace
*table 3 law & British colony
asdoc ta sandboxin lawsys, col chi save(t3_lawtab) replace
asdoc ta sandboxin lawsys if bcolony==1, col chi save(t3_lawtab)rowappend
asdoc ta sandboxin lawsys if commonwealth==1, col chi save(t3_lawtab)rowappend
*table 4 IOs
asdoc ta sandboxin BIS, col chi save(t4_IOtab) replace
asdoc ta sandboxin FSB, col chi save(t4_IOtab) rowappend
asdoc ta sandboxin BCBS, col chi save(t4_IOtab) rowappend
asdoc ta sandboxin IOSCO,col  chi save(t4_IOtab) rowappend
asdoc ta sandboxin AFI, col chi save(t4_IOtab) rowappend
*table 5 income
asdoc ta sandboxin income, col chi save(t5_incometab) replace
*table 6 Pro1 openness & competition
asdoc logit sandboxin lGDPPC lnpop2015 fiopenn forbasset, vce(r) save(t6_log) nest replace dec(3)
asdoc logit sandboxin lGDPPC lnpop2015 bankcon Hstat lerner boone , vce(r) save(t6_log) nest append dec(3)
asdoc logit sandboxin lGDPPC lnpop2015 bankcon, vce(r) save(t6_log) nest append dec(3)
asdoc logit sandboxin lGDPPC lnpop2015 stockcap bankcon lerner , vce(r) save(t6_log) nest append dec(3)
asdoc logit sandboxin lGDPPC lnpop2015 stockcap bankcon lerner boone , vce(r) save(t6_log) nest append dec(3)
asdoc logit sandboxin lGDPPC lnpop2015 fiopenn forbasset bankcon Hstat lerner boone , vce(r) save(t6_log) nest append dec(3)
*table 7 Pro2 law/British 
asdoc logit sandboxin lGDPPC lnpop2015 common, vce(r) save(t7_log2) nest replace
asdoc logit sandboxin lGDPPC lnpop2015 commonlaw, vce(r) save(t7_log2) nest append
asdoc logit sandboxin lGDPPC lnpop2015 common civil, vce(r) save(t7_log2) nest append
asdoc logit sandboxin lGDPPC lnpop2015 civil bcolony , vce(r) save(t7_log2) nest append
asdoc logit sandboxin lGDPPC lnpop2015 common bcolony, vce(r) save(t7_log2) nest append
*correlation between common law, british colony, and commonwealth countries
cor common bcolony
ta common bcolony
cor common commonwealth
ta civil bcolony, r chi

*table 8 pro3 IOs
asdoc logit sandboxin lGDPPC lnpop2015 BIS FSB BCBS IOSCO AFI, vce(r) save(t8_log3) nest replace
asdoc logit sandboxin lGDPPC lnpop2015 BCBS, vce(r) save(t8_log3) nest append
asdoc logit sandboxin lGDPPC lnpop2015 IOSCO, vce(r) save(t8_log3) nest append
asdoc logit sandboxin lGDPPC lnpop2015 AFI, vce(r) save(t8_log3) nest append
asdoc logit sandboxin lGDPPC lnpop2015 IOSCO bcolony, vce(r) save(t8_log3) nest append

logit sandboxin lGDPPC lnpop2015 i.IOSCO, vce(r)
margins IOSCO
margins r.IOSCO, contrast

*APPENDIX
*table 1 2 corr of stockcap and other INDV
asdoc corr sandboxin lGDPPC lnpop2015 fiopenn forbasset bankcon Hstat lerner boone  ///
  stockcap common commonlaw civil bcolony commonwealth, save(At_corIV) star (0.05) dec(2) replace
asdoc cor BIS-FATF, save(At_corIO) star (0.05) dec(2) replace
*table 3 APPlogit
asdoc logit sandboxin lGDPPC lnpop2015 fiopenn bankcon Hstat lerner boone common civil bcolony BIS FSB BCBS IOSCO AFI, vce(r) save(At_robust) nest replace
asdoc logit sandboxin lGDPPC lnpop2015 fiopenn bankcon Hstat lerner boone stockcap, vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 forbasset Hstat lerner boone , vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 fiopenn bankcon, vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 stockcap common civil bcolony BIS FSB BCBS AFI, vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 lerner common IOSCO , vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 common civil bcolony BCBS IOSCO, vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 civil common commonwealth, vce(r) save(At_robust) nest append
asdoc logit sandboxin lGDPPC lnpop2015 common commonwealth, vce(r) save(At_robust) nest append
*table 4 APPlogit2
asdoc logit sandboxin lGDPPC lnpop2015 BTCA CGAP CPMI CGFS IAIS FATF , vce(r) save(At_robust2) nest replace
asdoc logit sandboxin lGDPPC lnpop2015 BTCA CGAP CPMI CGFS IAIS , vce(r) save(At_robust2) nest append
asdoc logit sandboxin lGDPPC lnpop2015 CGAP CPMI CGFS IAIS , vce(r) save(At_robust2) nest append
asdoc logit sandboxin lGDPPC lnpop2015 CPMI CGFS IAIS , vce(r) save(At_robust2) nest append
